
/* A Bison parser, made by GNU Bison 2.4.1.  */

/* Skeleton interface for Bison's Yacc-like parsers in C
   
      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.
   
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.
   
   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */


/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     __SPAR_PUNCT_BEGIN = 258,
     _AMP_AMP = 259,
     _BACKQUOTE = 260,
     _BANG = 261,
     _BAR = 262,
     _BAR_BAR = 263,
     _CARET = 264,
     _CARET_CARET = 265,
     _COMMA = 266,
     _DOT = 267,
     _EQ = 268,
     _GE = 269,
     _GT = 270,
     _LBRA = 271,
     _LE = 272,
     _LPAR = 273,
     _LSQBRA = 274,
     _LT = 275,
     _MINUS = 276,
     _NOT_EQ = 277,
     _PLUS = 278,
     _PLUS_GT = 279,
     _QMARK = 280,
     _RBRA = 281,
     _RPAR = 282,
     _RSQBRA = 283,
     _SEMI = 284,
     _SLASH = 285,
     _STAR = 286,
     _STAR_GT = 287,
     a_L = 288,
     ADD_L = 289,
     ALL_L = 290,
     ALTER_L = 291,
     AS_L = 292,
     ASC_L = 293,
     ASK_L = 294,
     ASSUME_L = 295,
     ATTACH_L = 296,
     AVG_L = 297,
     BASE_L = 298,
     BIJECTION_L = 299,
     BIND_L = 300,
     BINDINGS_L = 301,
     BOUND_L = 302,
     BY_L = 303,
     CLASS_L = 304,
     CLEAR_L = 305,
     CREATE_L = 306,
     CONSTRUCT_L = 307,
     COPY_L = 308,
     COUNT_L = 309,
     COUNT_LPAR = 310,
     COUNT_DISTINCT_L = 311,
     DATA_L = 312,
     DATATYPE_L = 313,
     DEFAULT_L = 314,
     DEFINE_L = 315,
     DEFMACRO_L = 316,
     DELETE_L = 317,
     DEREF_L = 318,
     DESC_L = 319,
     DESCRIBE_L = 320,
     DETACH_L = 321,
     DISTINCT_L = 322,
     DROP_L = 323,
     EXCLUSIVE_L = 324,
     EXISTS_L = 325,
     false_L = 326,
     FILTER_L = 327,
     FROM_L = 328,
     FUNCTION_L = 329,
     GRAPH_L = 330,
     GROUP_L = 331,
     GROUP_CONCAT_L = 332,
     HAVING_L = 333,
     IDENTIFIED_L = 334,
     IFP_L = 335,
     IN_L = 336,
     INF_L = 337,
     INDEX_L = 338,
     INFERENCE_L = 339,
     INSERT_L = 340,
     INTO_L = 341,
     IRI_L = 342,
     LANG_L = 343,
     LIBRARY_L = 344,
     LIKE_L = 345,
     LIMIT_L = 346,
     LITERAL_L = 347,
     LOCAL_L = 348,
     LOAD_L = 349,
     MACRO_L = 350,
     MAKE_L = 351,
     MAP_L = 352,
     MAX_L = 353,
     MIN_L = 354,
     MINUS_L = 355,
     MODIFY_L = 356,
     MOVE_L = 357,
     NAMED_L = 358,
     NAN_L = 359,
     NIL_L = 360,
     NOT_L = 361,
     NOT_EXISTS_L = 362,
     NOT_FROM_L = 363,
     NOT_IN_L = 364,
     NOT_NULL_L = 365,
     NOT_USING_L = 366,
     NULL_L = 367,
     OBJECT_L = 368,
     OF_L = 369,
     OFFBAND_L = 370,
     OFFSET_L = 371,
     OPTIONAL_L = 372,
     OPTION_L = 373,
     ORDER_L = 374,
     PREDICATE_L = 375,
     PREFIX_L = 376,
     QUAD_L = 377,
     REDUCED_L = 378,
     RETURNS_L = 379,
     SAME_AS_L = 380,
     SAME_AS_O_L = 381,
     SAME_AS_P_L = 382,
     SAME_AS_S_L = 383,
     SAME_AS_S_O_L = 384,
     SAMPLE_L = 385,
     SCORE_L = 386,
     SCORE_LIMIT_L = 387,
     SELECT_L = 388,
     SERVICE_L = 389,
     SILENT_L = 390,
     SOFT_L = 391,
     SQLQUERY_L = 392,
     STORAGE_L = 393,
     SUBCLASS_L = 394,
     SUBJECT_L = 395,
     SUM_L = 396,
     TABLE_OPTION_L = 397,
     TEXT_L = 398,
     T_CYCLES_ONLY_L = 399,
     T_DIRECTION_L = 400,
     T_DISTINCT_L = 401,
     T_END_FLAG_L = 402,
     T_EXISTS_L = 403,
     T_FINAL_AS_L = 404,
     T_IN_L = 405,
     T_MAX_L = 406,
     T_MIN_L = 407,
     T_OUT_L = 408,
     T_NO_CYCLES_L = 409,
     T_NO_ORDER_L = 410,
     T_SHORTEST_ONLY_L = 411,
     T_STEP_L = 412,
     TO_L = 413,
     TRANSITIVE_L = 414,
     true_L = 415,
     UNBOUND_L = 416,
     UNDEF_L = 417,
     UNION_L = 418,
     USING_L = 419,
     VALUES_L = 420,
     WHERE_L = 421,
     WITH_L = 422,
     XML_L = 423,
     __SPAR_PUNCT_END = 424,
     START_OF_SPARQL_TEXT = 425,
     END_OF_SPARQL_TEXT = 426,
     SPARUL_RUN_SUBTYPE = 427,
     SPARUL_INSERT_DATA = 428,
     SPARUL_DELETE_DATA = 429,
     __SPAR_NONPUNCT_START = 430,
     SPARQL_BIF = 431,
     SPARQL_INTEGER = 432,
     SPARQL_DECIMAL = 433,
     SPARQL_DOUBLE = 434,
     SPARQL_STRING = 435,
     SPARQL_SQLTEXT = 436,
     LANGTAG = 437,
     QNAME = 438,
     QNAME_NS = 439,
     BLANK_NODE_LABEL = 440,
     Q_IRI_REF = 441,
     QD_VARNAME = 442,
     QD_COLON_PARAMNAME = 443,
     QD_COLON_PARAMNUM = 444,
     SPARQL_PLAIN_ID = 445,
     SPARQL_SQL_ALIASCOLNAME = 446,
     SPARQL_SQL_QTABLENAME = 447,
     SPARQL_SQL_QTABLECOLNAME = 448,
     __SPAR_NONPUNCT_END = 449,
     PRECODE_EXPN_PREC = 450,
     _COLON = 451,
     MATH_UMINUS = 452,
     MATH_UPLUS = 453,
     PPATH_ALTERNATIVE = 454,
     PPATH_SEQUENCE = 455,
     PPATH_CARET = 456,
     PPATH_MOD = 457,
     PPATH_BANG = 458
   };
#endif
/* Tokens.  */
#define __SPAR_PUNCT_BEGIN 258
#define _AMP_AMP 259
#define _BACKQUOTE 260
#define _BANG 261
#define _BAR 262
#define _BAR_BAR 263
#define _CARET 264
#define _CARET_CARET 265
#define _COMMA 266
#define _DOT 267
#define _EQ 268
#define _GE 269
#define _GT 270
#define _LBRA 271
#define _LE 272
#define _LPAR 273
#define _LSQBRA 274
#define _LT 275
#define _MINUS 276
#define _NOT_EQ 277
#define _PLUS 278
#define _PLUS_GT 279
#define _QMARK 280
#define _RBRA 281
#define _RPAR 282
#define _RSQBRA 283
#define _SEMI 284
#define _SLASH 285
#define _STAR 286
#define _STAR_GT 287
#define a_L 288
#define ADD_L 289
#define ALL_L 290
#define ALTER_L 291
#define AS_L 292
#define ASC_L 293
#define ASK_L 294
#define ASSUME_L 295
#define ATTACH_L 296
#define AVG_L 297
#define BASE_L 298
#define BIJECTION_L 299
#define BIND_L 300
#define BINDINGS_L 301
#define BOUND_L 302
#define BY_L 303
#define CLASS_L 304
#define CLEAR_L 305
#define CREATE_L 306
#define CONSTRUCT_L 307
#define COPY_L 308
#define COUNT_L 309
#define COUNT_LPAR 310
#define COUNT_DISTINCT_L 311
#define DATA_L 312
#define DATATYPE_L 313
#define DEFAULT_L 314
#define DEFINE_L 315
#define DEFMACRO_L 316
#define DELETE_L 317
#define DEREF_L 318
#define DESC_L 319
#define DESCRIBE_L 320
#define DETACH_L 321
#define DISTINCT_L 322
#define DROP_L 323
#define EXCLUSIVE_L 324
#define EXISTS_L 325
#define false_L 326
#define FILTER_L 327
#define FROM_L 328
#define FUNCTION_L 329
#define GRAPH_L 330
#define GROUP_L 331
#define GROUP_CONCAT_L 332
#define HAVING_L 333
#define IDENTIFIED_L 334
#define IFP_L 335
#define IN_L 336
#define INF_L 337
#define INDEX_L 338
#define INFERENCE_L 339
#define INSERT_L 340
#define INTO_L 341
#define IRI_L 342
#define LANG_L 343
#define LIBRARY_L 344
#define LIKE_L 345
#define LIMIT_L 346
#define LITERAL_L 347
#define LOCAL_L 348
#define LOAD_L 349
#define MACRO_L 350
#define MAKE_L 351
#define MAP_L 352
#define MAX_L 353
#define MIN_L 354
#define MINUS_L 355
#define MODIFY_L 356
#define MOVE_L 357
#define NAMED_L 358
#define NAN_L 359
#define NIL_L 360
#define NOT_L 361
#define NOT_EXISTS_L 362
#define NOT_FROM_L 363
#define NOT_IN_L 364
#define NOT_NULL_L 365
#define NOT_USING_L 366
#define NULL_L 367
#define OBJECT_L 368
#define OF_L 369
#define OFFBAND_L 370
#define OFFSET_L 371
#define OPTIONAL_L 372
#define OPTION_L 373
#define ORDER_L 374
#define PREDICATE_L 375
#define PREFIX_L 376
#define QUAD_L 377
#define REDUCED_L 378
#define RETURNS_L 379
#define SAME_AS_L 380
#define SAME_AS_O_L 381
#define SAME_AS_P_L 382
#define SAME_AS_S_L 383
#define SAME_AS_S_O_L 384
#define SAMPLE_L 385
#define SCORE_L 386
#define SCORE_LIMIT_L 387
#define SELECT_L 388
#define SERVICE_L 389
#define SILENT_L 390
#define SOFT_L 391
#define SQLQUERY_L 392
#define STORAGE_L 393
#define SUBCLASS_L 394
#define SUBJECT_L 395
#define SUM_L 396
#define TABLE_OPTION_L 397
#define TEXT_L 398
#define T_CYCLES_ONLY_L 399
#define T_DIRECTION_L 400
#define T_DISTINCT_L 401
#define T_END_FLAG_L 402
#define T_EXISTS_L 403
#define T_FINAL_AS_L 404
#define T_IN_L 405
#define T_MAX_L 406
#define T_MIN_L 407
#define T_OUT_L 408
#define T_NO_CYCLES_L 409
#define T_NO_ORDER_L 410
#define T_SHORTEST_ONLY_L 411
#define T_STEP_L 412
#define TO_L 413
#define TRANSITIVE_L 414
#define true_L 415
#define UNBOUND_L 416
#define UNDEF_L 417
#define UNION_L 418
#define USING_L 419
#define VALUES_L 420
#define WHERE_L 421
#define WITH_L 422
#define XML_L 423
#define __SPAR_PUNCT_END 424
#define START_OF_SPARQL_TEXT 425
#define END_OF_SPARQL_TEXT 426
#define SPARUL_RUN_SUBTYPE 427
#define SPARUL_INSERT_DATA 428
#define SPARUL_DELETE_DATA 429
#define __SPAR_NONPUNCT_START 430
#define SPARQL_BIF 431
#define SPARQL_INTEGER 432
#define SPARQL_DECIMAL 433
#define SPARQL_DOUBLE 434
#define SPARQL_STRING 435
#define SPARQL_SQLTEXT 436
#define LANGTAG 437
#define QNAME 438
#define QNAME_NS 439
#define BLANK_NODE_LABEL 440
#define Q_IRI_REF 441
#define QD_VARNAME 442
#define QD_COLON_PARAMNAME 443
#define QD_COLON_PARAMNUM 444
#define SPARQL_PLAIN_ID 445
#define SPARQL_SQL_ALIASCOLNAME 446
#define SPARQL_SQL_QTABLENAME 447
#define SPARQL_SQL_QTABLECOLNAME 448
#define __SPAR_NONPUNCT_END 449
#define PRECODE_EXPN_PREC 450
#define _COLON 451
#define MATH_UMINUS 452
#define MATH_UPLUS 453
#define PPATH_ALTERNATIVE 454
#define PPATH_SEQUENCE 455
#define PPATH_CARET 456
#define PPATH_MOD 457
#define PPATH_BANG 458




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
{

/* Line 1676 of yacc.c  */
#line 96 "./sparql_p.y"

  caddr_t box;
  caddr_t *boxes;
  ptrlong token_type;
  ptrlong nonboxed_int;
  SPART *tree;
  SPART **trees;
  dk_set_t list;
  dk_set_t backstack;
  spar_lexbmk_t *bookmark;
  void *nothing;



/* Line 1676 of yacc.c  */
#line 473 "sparql_p.h"
} YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
#endif




